/// <reference types="node" />
import * as http from 'http';
import { DB } from './db';
export interface IApiClass {
    get(req: http.IncomingMessage, res: http.ServerResponse, next: Function): void;
    post(req: http.IncomingMessage, res: http.ServerResponse, next: Function): void;
    put(req: http.IncomingMessage, res: http.ServerResponse, next: Function): void;
    patch(req: http.IncomingMessage, res: http.ServerResponse, next: Function): void;
    debug_get(req: http.IncomingMessage, res: http.ServerResponse, next: Function, prefix: string): void;
    debug_put(req: http.IncomingMessage, res: http.ServerResponse, next: Function): void;
    debug_delete(req: http.IncomingMessage, res: http.ServerResponse, next: Function): void;
}
export interface ApiDevStatus {
    id: string;
    wait: number;
    status: number;
    data: any;
    name: string;
}
export declare class BaseAPI implements IApiClass {
    private db;
    API_KEY: string;
    REG_EXP_PATH: string;
    /**
     * ローカルデータを取得する
     */
    readonly data: Promise<any>;
    /**
     * コンストラクタ
     * @param DB DBクラス
     * @param API_KEY API文字列
     * @param REG_EXP_PATH match url regexp string
     */
    constructor(db: DB, API_KEY: string, REG_EXP_PATH?: string);
    head(_req: http.IncomingMessage, res: http.ServerResponse, _next: Function): void;
    get(_req: http.IncomingMessage, res: http.ServerResponse, _next: Function): void;
    post(_req: http.IncomingMessage, res: http.ServerResponse, _next: Function): void;
    put(_req: http.IncomingMessage, res: http.ServerResponse, _next: Function): void;
    patch(_req: http.IncomingMessage, res: http.ServerResponse, _next: Function): void;
    delete(_req: http.IncomingMessage, res: http.ServerResponse, _next: Function): void;
    /**
     * 開発ステータスを返却する
     */
    debug_get(_req: http.IncomingMessage, res: http.ServerResponse, _next: Function, _prefix: string): void;
    /**
     * 開発ステータスを設定する
     * @param req
     * @param res
     * @param next
     */
    debug_put(req: http.IncomingMessage, res: http.ServerResponse, _next: Function): void;
    /**
     * 開発ステータスを再設定（初期化）する
     * @param req
     * @param res
     * @param next
     */
    debug_delete(_req: http.IncomingMessage, res: http.ServerResponse, _next: Function): void;
    /**
     * HTTPリクエストのbodyパラメーターを取得して返却する。
     * @param req
     */
    getBody(req: http.IncomingMessage): Promise<string>;
    /**
     * URLのパラメーターを取得する。
     * @param urlStr URL文字列
     */
    getRequestParameter(urlStr: string): Map<string, string>;
    /**
     * ステータスコード200のみを返す
     * @param req
     * @param res
     * @param next
     * @param statusCode 返却したいhttpステータスコード(任意)
     */
    nomaryResult(_req: http.IncomingMessage, res: http.ServerResponse, _next: Function, statusCode?: number): Promise<void>;
    /**
     * ローカルデータに引数のデータを追加する
     * @param obj 追加するObject (fixutre.dataがArrayでない場合は例外を投げる)
     */
    protected pushDB(obj: Object): Promise<any>;
    /**
     * APIにローカルに保持したデータを返却する
     * @param req
     * @param res
     * @param next
     */
    resultJSON(_req: http.IncomingMessage, res: http.ServerResponse, _next: Function): Promise<any>;
    /**
     * 画面に意図したデータを返却する
     * @param req
     * @param res
     * @param next
     * @param json
     */
    resultCustomJSON(_req: http.IncomingMessage, res: http.ServerResponse, _next: Function, json: any): Promise<any>;
    /**
     * ステータス返却
     */
    getDevelopState(): Promise<ApiDevStatus>;
}
