"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const url = require("url");
class BaseAPI {
    /**
     * コンストラクタ
     * @param DB DBクラス
     * @param API_KEY API文字列
     * @param REG_EXP_PATH match url regexp string
     */
    constructor(db, API_KEY, REG_EXP_PATH = '') {
        this.db = db;
        this.API_KEY = API_KEY;
        this.REG_EXP_PATH = REG_EXP_PATH;
    }
    /**
     * ローカルデータを取得する
     */
    get data() {
        return new Promise((resolve) => __awaiter(this, void 0, void 0, function* () {
            resolve(this.db.search(this.API_KEY));
        })).then((fixtre) => fixtre.data);
    }
    head(_req, res, _next) {
        res.setHeader('Content-Type', 'application/json');
        res.statusCode = 404;
        res.end(JSON.stringify({
            ERROR_MESSAGE: 'GET NOT FOUND',
        }));
    }
    get(_req, res, _next) {
        res.setHeader('Content-Type', 'application/json');
        res.statusCode = 404;
        res.end(JSON.stringify({
            ERROR_MESSAGE: 'GET NOT FOUND',
        }));
    }
    post(_req, res, _next) {
        res.setHeader('Content-Type', 'application/json');
        res.statusCode = 404;
        res.end(JSON.stringify({
            ERROR_MESSAGE: 'POST NOT FOUND',
        }));
    }
    put(_req, res, _next) {
        res.setHeader('Content-Type', 'application/json');
        res.statusCode = 404;
        res.end(JSON.stringify({
            ERROR_MESSAGE: 'PUT NOT FOUND',
        }));
    }
    patch(_req, res, _next) {
        res.setHeader('Content-Type', 'application/json');
        res.statusCode = 404;
        res.end(JSON.stringify({
            ERROR_MESSAGE: 'PATCH NOT FOUND',
        }));
    }
    delete(_req, res, _next) {
        res.setHeader('Content-Type', 'application/json');
        res.statusCode = 404;
        res.end(JSON.stringify({
            ERROR_MESSAGE: 'DELETE NOT FOUND',
        }));
    }
    /**
     * 開発ステータスを返却する
     */
    debug_get(_req, res, _next, _prefix) {
        this.getDevelopState()
            .then(status => {
            res.statusCode = 200;
            res.setHeader('Content-Type', 'application/json');
            res.end(JSON.stringify(Object.assign({}, status, { prefix: _prefix })));
        })
            .catch(e => console.log('e', e));
    }
    /**
     * 開発ステータスを設定する
     * @param req
     * @param res
     * @param next
     */
    debug_put(req, res, _next) {
        this.getBody(req).then((body) => __awaiter(this, void 0, void 0, function* () {
            const jsonBody = JSON.parse(body);
            yield this.db.create(this.API_KEY, jsonBody.data);
            yield this.db.setWait(this.API_KEY, jsonBody.wait);
            yield this.db.setState(this.API_KEY, jsonBody.status);
            res.statusCode = 200;
            res.setHeader('Content-Type', 'application/json');
            res.end(JSON.stringify({
                RESULT: 'SET DATA',
            }));
        }));
    }
    /**
     * 開発ステータスを再設定（初期化）する
     * @param req
     * @param res
     * @param next
     */
    debug_delete(_req, res, _next) {
        this.db
            .reload(this.API_KEY)
            .then(() => this.db.setState(this.API_KEY, 200))
            .then(() => this.db.setWait(this.API_KEY, 0))
            .then(() => {
            res.statusCode = 200;
            res.setHeader('Content-Type', 'application/json');
            res.end(JSON.stringify({
                RESULT: 'RESET DATA',
            }));
        });
    }
    /**
     * HTTPリクエストのbodyパラメーターを取得して返却する。
     * @param req
     */
    getBody(req) {
        return new Promise((resolve, reject) => {
            let body = '';
            req.on('readable', () => {
                body += req.read() || '';
            });
            req.on('end', () => {
                resolve(body);
            });
            req.on('error', reject);
        });
    }
    /**
     * URLのパラメーターを取得する。
     * @param urlStr URL文字列
     */
    getRequestParameter(urlStr) {
        const strQuery = (url.parse(urlStr).query || '');
        const aryQuery = strQuery.split('&');
        return strQuery
            ? aryQuery
                .map(query => ({
                key: query.split('=')[0],
                val: query.split('=')[1],
            }))
                .reduce((map, q) => map.set(q.key, decodeURIComponent(q.val)), new Map())
            : new Map();
    }
    /**
     * ステータスコード200のみを返す
     * @param req
     * @param res
     * @param next
     * @param statusCode 返却したいhttpステータスコード(任意)
     */
    nomaryResult(_req, res, _next, statusCode) {
        return __awaiter(this, void 0, void 0, function* () {
            const appParam = yield this.getDevelopState();
            setTimeout(() => {
                res.statusCode = statusCode || appParam.status;
                res.end();
            }, appParam.wait);
        });
    }
    /**
     * ローカルデータに引数のデータを追加する
     * @param obj 追加するObject (fixutre.dataがArrayでない場合は例外を投げる)
     */
    pushDB(obj) {
        return new Promise((resolve, reject) => __awaiter(this, void 0, void 0, function* () {
            const fixture = yield this.db.search(this.API_KEY);
            if (Array.isArray(fixture.data)) {
                fixture.data.push(obj);
                this.db.create(this.API_KEY, fixture.data).then(resolve);
            }
            else {
                reject(`${this.API_KEY} of data is not an Array`);
            }
        }));
    }
    /**
     * APIにローカルに保持したデータを返却する
     * @param req
     * @param res
     * @param next
     */
    resultJSON(_req, res, _next) {
        const resJSON = (resolve, reject) => __awaiter(this, void 0, void 0, function* () {
            const fixture = yield this.db.search(this.API_KEY);
            const appParam = yield this.getDevelopState();
            setTimeout(() => {
                res.statusCode = appParam.status;
                res.setHeader('Content-Type', 'application/json');
                res.end(JSON.stringify(fixture.data));
                res.on('error', e => reject(e));
                resolve();
            }, appParam.wait);
        });
        return new Promise(resJSON);
    }
    /**
     * 画面に意図したデータを返却する
     * @param req
     * @param res
     * @param next
     * @param json
     */
    resultCustomJSON(_req, res, _next, json) {
        const resJSON = (resolve, reject) => __awaiter(this, void 0, void 0, function* () {
            const appParam = yield this.getDevelopState();
            setTimeout(() => {
                res.statusCode = appParam.status;
                res.setHeader('Content-Type', 'application/json');
                res.end(JSON.stringify(json));
                res.on('error', e => reject(e));
                resolve();
            }, appParam.wait);
        });
        return new Promise(resJSON);
    }
    /**
     * ステータス返却
     */
    getDevelopState() {
        return __awaiter(this, void 0, void 0, function* () {
            const fixture = yield this.db.search(this.API_KEY);
            return {
                id: fixture.API_KEY,
                wait: fixture.dev.wait,
                status: fixture.dev.status,
                data: fixture.data,
                name: fixture.API_NAME,
            };
        });
    }
}
exports.BaseAPI = BaseAPI;
//# sourceMappingURL=base.api.js.map