"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const immutable_1 = require("immutable");
const fs_1 = require("fs");
const path_1 = require("path");
/**
 * やらないといけないこと
 * 1. 初期データのロード
 * 2. データの検索
 * 3. データの設定
 */
class DB {
    /**
     * Load initialize data;
     */
    constructor(fixtreDir, prefix = '') {
        this.fixtreDir = fixtreDir;
        this.prefix = prefix;
        /**
         * Immutable.Map()
         */
        this.DATA = immutable_1.Map();
        /**
         * JSONデータ用Prefix RegExp
         */
        this.JsonRxp = new RegExp('.json$');
        this.readFixture(fixtreDir).forEach(fixtre => this.setFixtureData(fixtre));
    }
    /**
     * searchd data
     * @param apiKey 取得するキー
     */
    search(apiKey) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.DATA.get(this.prefix + apiKey);
        });
    }
    /**
     * 指定したAPIキーのデータを再読込する
     */
    reload(apiKey) {
        return __awaiter(this, void 0, void 0, function* () {
            const updateAPIs = [
                ...this.readFixture(this.fixtreDir).filter((data) => data.API_KEY === apiKey),
            ];
            if (updateAPIs.length === 1) {
                this.DATA = this.DATA.set(this.prefix + apiKey, Object.assign({}, this.DATA.get(this.prefix + apiKey), { data: updateAPIs[0].data }));
            }
            else {
                throw Error('updateAPIs key not found');
            }
        });
    }
    create(apiKey, data) {
        return __awaiter(this, void 0, void 0, function* () {
            this.DATA = this.DATA.set(this.prefix + apiKey, Object.assign({}, this.DATA.get(this.prefix + apiKey), { data: data }));
        });
    }
    setWait(apiKey, wait) {
        return __awaiter(this, void 0, void 0, function* () {
            this.DATA = this.DATA.set(this.prefix + apiKey, Object.assign({}, this.DATA.get(this.prefix + apiKey), { dev: Object.assign({}, this.DATA.get(this.prefix + apiKey).dev, { wait: wait }) }));
        });
    }
    setState(apiKey, status) {
        return __awaiter(this, void 0, void 0, function* () {
            this.DATA = this.DATA.set(this.prefix + apiKey, Object.assign({}, this.DATA.get(this.prefix + apiKey), { dev: Object.assign({}, this.DATA.get(this.prefix + apiKey).dev, { status: status }) }));
        });
    }
    loadFixture(fullpath) {
        return JSON.parse(fs_1.readFileSync(fullpath, 'utf-8'));
    }
    setFixtureData(fixture) {
        this.DATA = this.DATA.set(this.prefix + fixture.API_KEY, Object.assign({}, fixture, { dev: {
                status: 200,
                wait: 0,
            } }));
    }
    readFixture(PATH) {
        return fs_1.readdirSync(PATH)
            .filter((file) => this.JsonRxp.test(file))
            .map(files => this.loadFixture(path_1.join(PATH, files)));
    }
}
exports.DB = DB;
//# sourceMappingURL=db.js.map