"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const createhandle_1 = require("./createhandle");
class UtilRouter {
    constructor(DB_BASE, prefix = '') {
        this.DB_BASE = DB_BASE;
        this.prefix = prefix;
        this.apiList = [];
    }
    /**
     * APIに共通ヘッダを設定する
     */
    addHeaderParameter() {
        return function MiddleHandle(_req, res, next) {
            res.setHeader('Access-Control-Allow-Origin', '*');
            next();
        };
    }
    /**
     * IDを含めた複雑なネストするポータル用APIの作成に利用する。
     * 少し重いので基本は createOpeApi の利用を推奨
     * @param uriRegExp マッチングするURL (正規表現)
     * @param API_KEY _fixutreのAPI_KEY件、dummyログイン画面のAPIとして利用する。
     * @param handleClass 対応するAPIの実装
     */
    createAppApi(handleClass) {
        return this.createRegExpApiFactory(handleClass);
    }
    apis(_apilist = this.apiList) {
        return {
            route: '/debug/apis',
            handle: (_req, res, _next) => {
                res.statusCode = 200;
                res.setHeader('Content-Type', 'application/json');
                res.end(JSON.stringify(_apilist));
            },
        };
    }
    createRegExpApiFactory(handleClass) {
        const handle = new handleClass(this.DB_BASE);
        const regExpUri = new RegExp(`^/${this.prefix ? this.prefix + '/' : ''}${handle.REG_EXP_PATH || handle.API_KEY}`);
        const handler = new createhandle_1.CreateHandle(handle);
        this.apiList.push(path_1.join(this.prefix, handle.API_KEY));
        const route = ['/debug', this.prefix, handle.API_KEY].filter(Boolean).join('/');
        return [
            MiddleHandle,
            {
                route: route,
                handle: (req, res, next) => handler.develop(req, res, next, this.prefix),
            },
        ];
        function MiddleHandle(req, res, next) {
            if (req.url && regExpUri.test(req.url)) {
                return handler.product(req, res, next);
            }
            else {
                return next();
            }
        }
    }
}
exports.UtilRouter = UtilRouter;
//# sourceMappingURL=uri-router.js.map